Fields
name: Stringmetadata: BTreeMap<String, String>Trait Implementations
sourceimpl BinRead for Metadata
impl BinRead for Metadata
sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_options: &ReadOptions,
__binrw_generated_var_arguments: Self::Args
) -> BinResult<Self>
fn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_options: &ReadOptions,
__binrw_generated_var_arguments: Self::Args
) -> BinResult<Self>
sourceimpl BinWrite for Metadata
impl BinWrite for Metadata
type Args = ()
type Args = ()
The type of arguments needed to be supplied in order to write this type, usually a tuple. Read more
sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_options: &WriteOptions,
__binrw_generated_var_arguments: Self::Args
) -> BinResult<()>
fn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_options: &WriteOptions,
__binrw_generated_var_arguments: Self::Args
) -> BinResult<()>
Write the type to a writer, given the options on how to write it and the type-specific
arguments Read more